package com.ruoyi.interfaces.service;

import com.ruoyi.interfaces.domain.MdModelCatetory;

import java.util.List;

/**
 * 模型目录Service接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
public interface IMdModelCatetoryService 
{
    /**
     * 查询模型目录
     * 
     * @param cateid 模型目录主键
     * @return 模型目录
     */
    public MdModelCatetory selectMdModelCatetoryByCateid(String cateid);

    /**
     * 查询模型目录列表
     * 
     * @param mdModelCatetory 模型目录
     * @return 模型目录集合
     */
    public List<MdModelCatetory> selectMdModelCatetoryList(MdModelCatetory mdModelCatetory);

    /**
     * 新增模型目录
     * 
     * @param mdModelCatetory 模型目录
     * @return 结果
     */
    public int insertMdModelCatetory(MdModelCatetory mdModelCatetory);

    /**
     * 修改模型目录
     * 
     * @param mdModelCatetory 模型目录
     * @return 结果
     */
    public int updateMdModelCatetory(MdModelCatetory mdModelCatetory);

    /**
     * 批量删除模型目录
     * 
     * @param cateids 需要删除的模型目录主键集合
     * @return 结果
     */
    public int deleteMdModelCatetoryByCateids(String[] cateids);

    /**
     * 删除模型目录信息
     * 
     * @param cateid 模型目录主键
     * @return 结果
     */
    public int deleteMdModelCatetoryByCateid(String cateid);
}